==> hashikake-0.1.0.zip: src/jp/gr/java_conf/ktz/puzzle/hashikake/view/BoardView.java <==
// ***************************************************************************************
//
//	Copyright (C) 2003 Kazuhiko TAMURA. All rights reserved.
//
//	This program is free software; you can redistribute it and/or 
//	modify it under the terms of the GNU General Public License
//	as published by the Free Software Foundation; either version 2
//	of the License, or (at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//	NAME:		BoardView.java
//	DATE:		2003.6.9
//	CREATOR:	Kazuhiko TAMURA
//
// ***************************************************************************************

package jp.gr.java_conf.ktz.puzzle.hashikake.view;

import java.io.File;

import java.awt.Component;

import jp.gr.java_conf.ktz.puzzle.framework.ProblemInfo;

import jp.gr.java_conf.ktz.puzzle.hashikake.util.SaveCanceledException;

/**
 *	ViewKw̃C^[tF[X
 */
public interface BoardView {
	/**
	 *	Ֆʂ̏s
	 */
	public void initialize();
	
	/**
	 *	BoardKwƂÅKw̐eݒ肷
	 *
	 *	@param	inBoard	̊Kw̐eƂȂBoard
	 */
	public void setParent(BoardView inBoard);
	
	/**
	 *	Board̃TCYύX
	 *
	 *	@param	inWidth ύX̕
	 *	@param	inHeight ύX̍
	 */	
	public void createBoard(final int inWidth, final int inHeight);
	
	/**
	 *	@return Board̕Ԃ
	 */
	public int getBoardWidth();

	/**
	 *	@return Board̍Ԃ
	 */
	public int getBoardHeight();
	
	/**
	 *	w肵t@CɁA쐬蕶ۑ
	 *
	 *	@param	inFile ۑƂȂt@C
	 */
	public void save(File inFile) throws SaveCanceledException;
	
	/**
	 *	w肵蕶load
	 *
	 *	@param inInfo 
	 */
	public void load(ProblemInfo inInfo);
	
	/**
	 *	ՖʂύXĂ邩ǂ`FbNB
	 */
	public boolean isModified();
	
	/**
	 *	ՖʂԂɖ߂
	 */
	public void clear();
	
	/**
	 *	@return	gƊ֘AtꂽCOmponentԂ
	 */
	public Component getComponent();
	
	/**
	 *	w肵^CgZbg
	 *
	 *	@param	^Cg
	 */
	public void setTitle(String inTitle);
	
	/**
	 *	Board̃^CgԂ
	 *
	 *	@return	^Cg
	 */
	public String getTitle();
	
	/**
	 *	Boardĕ`悷
	 */
	public void repaint();
	
	/**
	 *	Board1s[X̃TCYZbg
	 *
	 *	@param	inSize ZTCY
	 */
	public void setPieceSize(final int inSize);
	
	/**
	 *	Board1s[X̃TCYԂ
	 *
	 *	@return ZTCY
	 */
	public int getPieceSize();
	
	/**
	 *	Board̃TCYZbg
	 *
	 *	@param	inWidth 
	 *	@param	inHeight 
	 */
	public void setComponentSize(final int inWidth, final int inHeight);
	
	/**
	 *	BoardɃtH[JXڂǂ߂
	 */
	public void setFocus(boolean inFocused);
	
	/**
	 *	BoardɃtH[JX݂邩ǂ`FbN
	 *
	 *	@return	tH[JXꍇtrueԂB
	 */
	public boolean isFocused();
}

==> hashikake-0.3.0.zip: src/jp/gr/java_conf/ktz/puzzle/hashikake/view/BoardView.java <==
// ***************************************************************************************
//
//	Copyright (C) 2003 Kazuhiko TAMURA. All rights reserved.
//
//	This program is free software; you can redistribute it and/or 
//	modify it under the terms of the GNU General Public License
//	as published by the Free Software Foundation; either version 2
//	of the License, or (at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
//
//	NAME:		BoardView.java
//	DATE:		2003.6.9
//	CREATOR:	Kazuhiko TAMURA
//
// ***************************************************************************************

package jp.gr.java_conf.ktz.puzzle.hashikake.view;

import java.io.File;

import java.awt.Component;

import jp.gr.java_conf.ktz.puzzle.framework.ProblemInfo;

import jp.gr.java_conf.ktz.puzzle.hashikake.util.SaveCanceledException;
import jp.gr.java_conf.ktz.puzzle.hashikake.util.Command;

/**
 *	ViewKw̃C^[tF[X
 */
public interface BoardView extends CommandContainer {
	/**
	 *	Ֆʂ̏s
	 */
	public void initialize();
	
	/**
	 *	BoardKwƂÅKw̐eݒ肷
	 *
	 *	@param	inBoard	̊Kw̐eƂȂBoard
	 */
	public void setParent(BoardView inBoard);
	
	/**
	 *	w肵t@CɁA쐬蕶ۑ
	 *
	 *	@param	inFile ۑƂȂt@C
	 */
	public void save(File inFile) throws SaveCanceledException;
	
	/**
	 *	w肵蕶load
	 *
	 *	@param inInfo 
	 */
	public void load(ProblemInfo inInfo);
	
	/**
	 *	ՖʂύXĂ邩ǂ`FbNB
	 */
	public boolean isModified();
	
	/**
	 *	ՖʂԂɖ߂
	 */
	public void clear();
	
	/**
	 *	@return	gƊ֘AtꂽCOmponentԂ
	 */
	public Component getComponent();
	
	/**
	 *	w肵^CgZbg
	 *	versioncommandx[Xɐ؂ւ
	 *
	 *	@param	^Cg
	 */
	public void setTitle(String inTitle);
	
	/**
	 *	Boardĕ`悷
	 */
	public void repaint();
	
	/**
	 *	BoardɃtH[JXڂǂ߂
	 */
	public void setFocus(boolean inFocused);
	
	/**
	 *	BoardɃtH[JX݂邩ǂ`FbN
	 *
	 *	@return	tH[JXꍇtrueԂB
	 */
	public boolean isFocused();
}
